@@ -69,9 +69,10 @@ class DefaultTask(Task):
                         count += 1
 
                 if count > 0 and count % self._progress_report_frequency == 0:
-                    LOGGER.info(f'Extracted %i records so far', count)
+                    LOGGER.info(f'Extracted {count} records so far')
 
                 # Prepare the next record
                 record = self.extractor.extract()
+            LOGGER.info(f'Total extracted records: {count}')
         finally:
             self._closer.close()
